Les Olympiades de Val Parisis édition 2017

Val Parisis Agglo

Les Olympiades de Val Parisis édition 2017

Samedi 1er juillet, 450 enfants des 15 communes de Val Parisis vont se retrouver pour une journée sportive et amicale placée sous le signe de l’olympisme au Centre départemental de Formation et d’Animation sportives (CDFAS) à Eaubonne.
Venez les encourager !
http://bit.ly/2rgM9rr
À cette occasion, Val Parisis soutient la candidature de Paris pour l'obtention des Jeux Olympiques en 2024.

19/06/2017